# eis-accounting
The EMIL GdvService API description

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.accounting
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import eis.accounting
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.accounting
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.accounting
from pprint import pprint
from eis.accounting.api import health_api
from eis.accounting.model.inline_response200 import InlineResponse200
from eis.accounting.model.inline_response503 import InlineResponse503
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.accounting.Configuration(
    host = "https://apiv2.emil.de"
)



# Enter a context with an instance of the API client
with eis.accounting.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = health_api.HealthApi(api_client)

    try:
        # Health Check
        api_response = api_instance.check()
        pprint(api_response)
    except eis.accounting.ApiException as e:
        print("Exception when calling HealthApi->check: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*HealthApi* | [**check**](docs/HealthApi.md#check) | **GET** /gdvservice/health | Health Check
*MailboxApi* | [**create_mailbox**](docs/MailboxApi.md#create_mailbox) | **POST** /gdvservice/v1/mailboxes | Create the Mailbox
*MailboxApi* | [**download_messages**](docs/MailboxApi.md#download_messages) | **POST** /gdvservice/v1/mailboxes/download-messages | Create the download-messages
*MessagesApi* | [**get_request_message**](docs/MessagesApi.md#get_request_message) | **GET** /gdvservice/v1/messages/requests/{code} | Retrieve the request message
*MessagesApi* | [**get_response_message**](docs/MessagesApi.md#get_response_message) | **GET** /gdvservice/v1/messages/responses/{code} | Retrieve the response message
*MessagesApi* | [**list_all_messages**](docs/MessagesApi.md#list_all_messages) | **GET** /gdvservice/v1/messages | List messages
*MessagesApi* | [**list_requests_messages**](docs/MessagesApi.md#list_requests_messages) | **GET** /gdvservice/v1/messages/requests | List requests messages
*MessagesApi* | [**list_responses_messages**](docs/MessagesApi.md#list_responses_messages) | **GET** /gdvservice/v1/messages/responses | List responses messages
*MessagesApi* | [**update_request_message**](docs/MessagesApi.md#update_request_message) | **PUT** /gdvservice/v1/messages/requests/{code} | Update the request message
*MessagesApi* | [**update_response_message**](docs/MessagesApi.md#update_response_message) | **PUT** /gdvservice/v1/messages/responses/{code} | Update the request message
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /gdvservice/v1/users | Create the gdv tenant user
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /gdvservice/v1/users/{code} | Retrieve the gdv tenant user
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /gdvservice/v1/users | List gdv tenant users
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /gdvservice/v1/users/{code} | Update the gdv tenant user
*VbasApi* | [**create_vba**](docs/VbasApi.md#create_vba) | **POST** /gdvservice/v1/vbas | Create the vba
*VbasApi* | [**get_vba**](docs/VbasApi.md#get_vba) | **GET** /gdvservice/v1/vbas/{code} | Retrieve the vba
*VbasApi* | [**list_vbas**](docs/VbasApi.md#list_vbas) | **GET** /gdvservice/v1/vbas | List vbas
*VbasApi* | [**update_vba**](docs/VbasApi.md#update_vba) | **PUT** /gdvservice/v1/vbas/{code} | Update the vba
*VbusApi* | [**create_vbu**](docs/VbusApi.md#create_vbu) | **POST** /gdvservice/v1/vbus/create-vbu | Create the vbu
*VbusApi* | [**create_vbuv**](docs/VbusApi.md#create_vbuv) | **POST** /gdvservice/v1/vbus/create-vbuv | Create the vbu
*VbusApi* | [**get_vbu**](docs/VbusApi.md#get_vbu) | **GET** /gdvservice/v1/vbus/{code} | Retrieve the vbu
*VbusApi* | [**list_vbus**](docs/VbusApi.md#list_vbus) | **GET** /gdvservice/v1/vbus | List vbus
*VbusApi* | [**update_vbu**](docs/VbusApi.md#update_vbu) | **PUT** /gdvservice/v1/vbus/{code} | Update the vbu
*ZipCodesApi* | [**get_zip_code**](docs/ZipCodesApi.md#get_zip_code) | **GET** /gdvservice/v1/zipcodes/{code} | Retrieve the zip code
*ZipCodesApi* | [**list_zip_codes**](docs/ZipCodesApi.md#list_zip_codes) | **GET** /gdvservice/v1/zipcodes | List zip codes
*ZipCodesApi* | [**store_zip_codes**](docs/ZipCodesApi.md#store_zip_codes) | **POST** /gdvservice/v1/zipcodes | Create the zip codes


## Documentation For Models

 - [AddressClass](docs/AddressClass.md)
 - [CreateMailboxRequestDto](docs/CreateMailboxRequestDto.md)
 - [CreateUserRequestDto](docs/CreateUserRequestDto.md)
 - [CreateUserResponseClass](docs/CreateUserResponseClass.md)
 - [CreateVbaRequestDto](docs/CreateVbaRequestDto.md)
 - [CreateVbaResponseClass](docs/CreateVbaResponseClass.md)
 - [CreateVbuRequestDto](docs/CreateVbuRequestDto.md)
 - [CreateVbuResponseClass](docs/CreateVbuResponseClass.md)
 - [CreateVbuvRequestDto](docs/CreateVbuvRequestDto.md)
 - [CreateVbuvResponseClass](docs/CreateVbuvResponseClass.md)
 - [GetRequestMessageResponseClass](docs/GetRequestMessageResponseClass.md)
 - [GetResponseMessageResponseClass](docs/GetResponseMessageResponseClass.md)
 - [GetUserResponseClass](docs/GetUserResponseClass.md)
 - [GetVbaResponseClass](docs/GetVbaResponseClass.md)
 - [GetVbuResponseClass](docs/GetVbuResponseClass.md)
 - [GetZipCodeResponseClass](docs/GetZipCodeResponseClass.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [ListAllMessagesResponseClass](docs/ListAllMessagesResponseClass.md)
 - [ListRequestsMessagesResponseClass](docs/ListRequestsMessagesResponseClass.md)
 - [ListResponsesMessagesResponseClass](docs/ListResponsesMessagesResponseClass.md)
 - [ListUsersResponseClass](docs/ListUsersResponseClass.md)
 - [ListVbasResponseClass](docs/ListVbasResponseClass.md)
 - [ListVbusResponseClass](docs/ListVbusResponseClass.md)
 - [ListZipCodesResponseClass](docs/ListZipCodesResponseClass.md)
 - [MessageClass](docs/MessageClass.md)
 - [RequestDetailsClass](docs/RequestDetailsClass.md)
 - [RequestMessageClass](docs/RequestMessageClass.md)
 - [ResponseDetailsClass](docs/ResponseDetailsClass.md)
 - [ResponseMessageClass](docs/ResponseMessageClass.md)
 - [StoreZipCodesRequestDto](docs/StoreZipCodesRequestDto.md)
 - [StoreZipCodesResponseClass](docs/StoreZipCodesResponseClass.md)
 - [UpdateRequestMessageRequestDto](docs/UpdateRequestMessageRequestDto.md)
 - [UpdateRequestMessageResponseClass](docs/UpdateRequestMessageResponseClass.md)
 - [UpdateResponseMessageRequestDto](docs/UpdateResponseMessageRequestDto.md)
 - [UpdateResponseMessageResponseClass](docs/UpdateResponseMessageResponseClass.md)
 - [UpdateUserRequestDto](docs/UpdateUserRequestDto.md)
 - [UpdateUserResponseClass](docs/UpdateUserResponseClass.md)
 - [UpdateVbaRequestDto](docs/UpdateVbaRequestDto.md)
 - [UpdateVbuRequestDto](docs/UpdateVbuRequestDto.md)
 - [UpdateVbuResponseClass](docs/UpdateVbuResponseClass.md)
 - [UserClass](docs/UserClass.md)
 - [VbaClass](docs/VbaClass.md)
 - [VbaResponseClass](docs/VbaResponseClass.md)
 - [VbuClass](docs/VbuClass.md)
 - [VbuResponseClass](docs/VbuResponseClass.md)
 - [XlsxZipCodeDto](docs/XlsxZipCodeDto.md)
 - [ZipCodeClass](docs/ZipCodeClass.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.accounting.apis and eis.accounting.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.accounting.api.default_api import DefaultApi`
- `from eis.accounting.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.accounting
from eis.accounting.apis import *
from eis.accounting.models import *
```

